@@ -1,6 +1,6 @@
 #!perl -w
 #
-# $Id: exe_opt.pl,v 1.19 2010/11/21 18:10:23 rmeden Exp $
+# $Id: exe_opt.pl,v 1.21 2012/02/11 19:33:36 rmeden Exp $
 #
 # This is a simple script to generate options so PerlApp can make the EXE
 # it needs time values, so might as well put it in a perl script!
@@ -23,6 +23,7 @@ print '-nologo
 -add "DateTime::Locale::en_US"
 -add "DateTime::TimeZone::Europe::Copenhagen"
 -add "DateTime::TimeZone::Europe::Helsinki"
+-add "DateTime::TimeZone::Europe::Lisbon"
 -add "DateTime::TimeZone::Asia::Jerusalem"
 -add "DateTime::TimeZone::Asia::Kolkata"
 -add="Tk::ProgressBar"
@@ -31,7 +32,6 @@ print '-nologo
 -trim="Apache::Const;Apache::RequestIO;DIME::Payload;MIME::Entity;Apache::RequestRec;DIME::Message;I18N::Langinfo"
 -trim="Apache2::RequestUtil;APR::Table;Apache2::Const;Apache2::RequestRec;Apache2::RequestIO"
 -trim=DateTime::Format
--trim=grab/eu_epgdata/tv_grab_eu_epgdata
 -info CompanyName="XMLTV Project http://www.xmltv.org"
 -info FileDescription="EXE bundle of XMLTV tools to manage TV Listings"
 -info InternalName=xmltv.exe
