@@ -1,6 +1,6 @@
 #!perl -w
 #
-# $Id: exe_wrap.pl,v 1.90 2011/06/22 06:08:48 rmeden Exp $
+# $Id: exe_wrap.pl,v 1.93 2012/06/14 06:59:46 rmeden Exp $
 # This is a quick XMLTV shell routing to use with the windows exe
 #
 # A single EXE is needed to allow sharing of modules and dlls of all the
@@ -69,24 +69,12 @@ print STDERR "Timezone is $ENV{TZ}\n" unless $opt_quiet;
 $cmd = shift || "";
 
 # --version (and abbreviations thereof)
-my $VERSION = '0.5.61';
+my $VERSION = '0.5.63';
 if (index('--version', $cmd) == 0 and length $cmd >= 3) {
     print "xmltv $VERSION\n";
     exit;
 }
 
-#
-# some grabbers aren't included
-#
-if ($cmd =~ /^tv_grab_(eu_epgdata)$/) {
-    die <<END
-Sorry, $cmd is not available in this Windows binary release, although
-it is included in xmltv source releases.
-
-END
-  ;
-};
-
 #
 # some programs use a "share" directory
 #
@@ -136,8 +124,7 @@ foreach my $exe (split(/ /,$files))
 {
     next unless length($exe)>3; #ignore trash
     $_=$exe;
-    s!^.+/!!g;
-    next if /epgdata/;
+    s!^.+/!!g;   
     $cmds{$_}=1;  # build command list (just in case)
 
     next unless $cmd eq $_;
